pkglts\.option\.git package
===========================

Submodules
----------

pkglts\.option\.git\.config module
----------------------------------

.. automodule:: pkglts.option.git.config
    :members:
    :undoc-members:
    :show-inheritance:

pkglts\.option\.git\.handlers module
------------------------------------

.. automodule:: pkglts.option.git.handlers
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pkglts.option.git
    :members:
    :undoc-members:
    :show-inheritance:
